<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da_DK">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About </source>
        <translation>Om </translation>
    </message>
    <message>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Forfatter</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donér</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Luk</translation>
    </message>
    <message>
        <source>Contact</source>
        <translation>Kontakt</translation>
    </message>
</context>
<context>
    <name>AboutTab</name>
    <message>
        <source>License: </source>
        <translation>Licens: </translation>
    </message>
    <message>
        <source>Screenshot and Annotation Tool</source>
        <translation>Skærmbillede- og annoteringsværktøj</translation>
    </message>
</context>
<context>
    <name>ActionSettingTab</name>
    <message>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Genvej</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Ryd</translation>
    </message>
    <message>
        <source>Take Capture</source>
        <translation>Tag Skærmbillede</translation>
    </message>
    <message>
        <source>Include Cursor</source>
        <translation>Medtag Musmarkøren</translation>
    </message>
    <message>
        <source>Delay</source>
        <translation>Udsæt</translation>
    </message>
    <message>
        <source>s</source>
        <extracomment>The small letter s stands for seconds.</extracomment>
        <translation>s</translation>
    </message>
    <message>
        <source>Capture Mode</source>
        <translation>Optagelsesmåde</translation>
    </message>
    <message>
        <source>Show image in Pin Window</source>
        <translation>Vis Billede I Fastgjort Vindue</translation>
    </message>
    <message>
        <source>Copy image to Clipboard</source>
        <translation>Kopier Billede Til Udklipsholder</translation>
    </message>
    <message>
        <source>Upload image</source>
        <translation>Upload Billede</translation>
    </message>
    <message>
        <source>Open image parent directory</source>
        <translation>Åbn Billedes Overordnet Mappe</translation>
    </message>
    <message>
        <source>Save image</source>
        <translation>Gem Billede</translation>
    </message>
    <message>
        <source>Hide Main Window</source>
        <translation>Skjul Hovedvindue</translation>
    </message>
    <message>
        <source>Global</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When enabled will make the shortcut
available even when ksnip has no focus.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ActionsSettings</name>
    <message>
        <source>Add</source>
        <translation>Tilføj</translation>
    </message>
    <message>
        <source>Actions Settings</source>
        <translation>Handlingsindstillinger</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Handling</translation>
    </message>
</context>
<context>
    <name>AddWatermarkOperation</name>
    <message>
        <source>Watermark Image Required</source>
        <translation>Vandmærke billede krævet</translation>
    </message>
    <message>
        <source>Please add a Watermark Image via Options &gt; Settings &gt; Annotator &gt; Update</source>
        <translation>Vær sød at tilføje vandmærket billede via Valg &gt; Indstillinger &gt; Annotator &gt; Opdateringer</translation>
    </message>
</context>
<context>
    <name>AnnotationSettings</name>
    <message>
        <source>Smooth Painter Paths</source>
        <translation type="unfinished">Jævn malede stier</translation>
    </message>
    <message>
        <source>When enabled smooths out pen and
marker paths after finished drawing.</source>
        <translation>Når aktiveret, og når tegning er færdig,
jævner blyant og markørs linier ud.</translation>
    </message>
    <message>
        <source>Smooth Factor</source>
        <translation>Udjævningsfaktor</translation>
    </message>
    <message>
        <source>Increasing the smooth factor will decrease
precision for pen and marker but will
make them more smooth.</source>
        <translation>Forhøjelse af udjævningsfaktoren vil forringe
blyants og markørs nøjagtighed, men vil også
gør dem mere jævne.</translation>
    </message>
    <message>
        <source>Annotator Settings</source>
        <translation>Annotator Indstillinger</translation>
    </message>
    <message>
        <source>Remember annotation tool selection and load on startup</source>
        <translation>Husk annoteringsværktøjsvalg og indlæs det ved computer opstart</translation>
    </message>
    <message>
        <source>Switch to Select Tool after drawing Item</source>
        <translation>Når du er færdig med at tegne et element, skift til Vælg Værktøj menu</translation>
    </message>
    <message>
        <source>Number Tool Seed change updates all Number Items</source>
        <translation>Med ændring af Tæller Værktøj, opdateres alle nummeriske elementer</translation>
    </message>
    <message>
        <source>Disabling this option causes changes of the number tool
seed to affect only new items but not existing items.
Disabling this option allows having duplicate numbers.</source>
        <translation>Deaktivering af dette her valg betyder at nummereringsværktøjet påvirker kun de nye elementer, og ikke de gamle.
Deaktivering lader dig anvende dubletnumre.</translation>
    </message>
    <message>
        <source>Canvas Color</source>
        <translation>Kanvas Farve</translation>
    </message>
    <message>
        <source>Default Canvas background color for annotation area.
Changing color affects only new annotation areas.</source>
        <translation>Standard kanvas baggrundsfarve for annoteringsområde.
Farveændring påvirker kun de nye annoteringsområder.</translation>
    </message>
    <message>
        <source>Select Item after drawing</source>
        <translation>Valg element når tegning er færdig</translation>
    </message>
    <message>
        <source>With this option enabled the item gets selected after
being created, allowing changing settings.</source>
        <translation>Med denne valgmulighed aktiveret, markeres elementet
lige efter det er blevet tegnet, hvilket gør det muligt at ændre indstillingerne.</translation>
    </message>
    <message>
        <source>Show Controls Widget</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Controls Widget contains the Undo/Redo,
Crop, Scale, Rotate and Modify Canvas buttons.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ApplicationSettings</name>
    <message>
        <source>Capture screenshot at startup with default mode</source>
        <translation>Tag skærmbillede i standard måde ved computerens opstart</translation>
    </message>
    <message>
        <source>Application Style</source>
        <translation>Programmets Brugergrænseflade</translation>
    </message>
    <message>
        <source>Sets the application style which defines the look and feel of the GUI.
Change requires ksnip restart to take effect.</source>
        <translation>Indstiller programmets brugergrænseflade og på den måde definerer
den overordnede grafiske brugergrænseflade. For at få ændringerne til at træde i kraft, skal Ksnip genstartes.</translation>
    </message>
    <message>
        <source>Application Settings</source>
        <translation>Programindstillinger</translation>
    </message>
    <message>
        <source>Automatically copy new captures to clipboard</source>
        <translation>Kopier automatisk de nye skærmbilleder til udklipsholderen</translation>
    </message>
    <message>
        <source>Use Tabs</source>
        <translation>Brug faneblade</translation>
    </message>
    <message>
        <source>Change requires restart.</source>
        <translation>Ændring kræver genstart.</translation>
    </message>
    <message>
        <source>Run ksnip as single instance</source>
        <translation>Kør Ksnip som enkelt instans</translation>
    </message>
    <message>
        <source>Hide Tabbar when only one Tab is used.</source>
        <translation>Skjul fanebladslinjen når kun et faneblad bruges.</translation>
    </message>
    <message>
        <source>Enabling this option will allow only one ksnip instance to run,
all other instances started after the first will pass its
arguments to the first and close. Changing this option requires
a new start of all instances.</source>
        <translation type="unfinished">Aktivering af denne valgmulighed vil lade kun et Ksnip instans at køre,
alle andre instanser der starter bagefter vil overføre deres argumenter til det første, og derefter lukke.</translation>
    </message>
    <message>
        <source>Remember Main Window position on move and load on startup</source>
        <translation>Husk hovedvinduets placering ved flyttning og indlæs den ved opstart</translation>
    </message>
    <message>
        <source>Auto hide Tabs</source>
        <translation>Skjul automatisk faneblade</translation>
    </message>
    <message>
        <source>Auto hide Docks</source>
        <translation>Skjul Docks/Faner Automatisk</translation>
    </message>
    <message>
        <source>On startup hide Toolbar and Annotation Settings.
Docks visibility can be toggled with the Tab Key.</source>
        <translation>Ved opstart, skjul værktøjslinjen og annoteringsindstillingerne.
Dockens synlighed kan slås til og fra med Tab tasten</translation>
    </message>
    <message>
        <source>Auto resize to content</source>
        <translation>Tilpas automatisk til indholdet</translation>
    </message>
    <message>
        <source>Automatically resize Main Window to fit content image.</source>
        <translation>Skaler automatisk hovedvinduet og tilpas det til skærmbilledet.</translation>
    </message>
    <message>
        <source>Enable Debugging</source>
        <translation>Aktiver fejlsøgning</translation>
    </message>
    <message>
        <source>Enables debug output written to the console.
Change requires ksnip restart to take effect.</source>
        <translation>Aktiverer fejlsøgnings udskrift i terminalen.
Ændringen træder i kraft efter Ksnips genstart.</translation>
    </message>
    <message>
        <source>Resizing to content is delay to allow the Window Manager to receive
the new content. In case that the Main Windows is not adjusted correctly
to the new content, increasing this delay might improve the behavior.</source>
        <translation type="unfinished">???</translation>
    </message>
    <message>
        <source>Resize delay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Temp Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Temp directory used for storing temporary images that are
going to be deleted after ksnip closes.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse</source>
        <translation type="unfinished">Gennemse</translation>
    </message>
</context>
<context>
    <name>AuthorTab</name>
    <message>
        <source>Contributors:</source>
        <translation>Bidragydere:</translation>
    </message>
    <message>
        <source>Spanish Translation</source>
        <translation>Spansk oversættelse</translation>
    </message>
    <message>
        <source>Dutch Translation</source>
        <translation>Hollandsk oversættelse</translation>
    </message>
    <message>
        <source>Russian Translation</source>
        <translation>Russisk oversættelse</translation>
    </message>
    <message>
        <source>Norwegian Bokmål Translation</source>
        <translation>Norsk bokmål oversættelse</translation>
    </message>
    <message>
        <source>French Translation</source>
        <translation>Fransk oversættelse</translation>
    </message>
    <message>
        <source>Polish Translation</source>
        <translation>Polsk oversættelse</translation>
    </message>
    <message>
        <source>Snap &amp; Flatpak Support</source>
        <translation>Snap &amp; Flatpak support</translation>
    </message>
    <message>
        <source>The Authors:</source>
        <translation>Ophavsmænd:</translation>
    </message>
</context>
<context>
    <name>CanDiscardOperation</name>
    <message>
        <source>Warning - </source>
        <translation>Advarsel - </translation>
    </message>
    <message>
        <source>The capture %1%2%3 has been modified.
Do you want to save it?</source>
        <translation>Skærmbilledet %1%2%3 er blevet ændret.
Vil du gemme ændringerne?</translation>
    </message>
</context>
<context>
    <name>CaptureModePicker</name>
    <message>
        <source>New</source>
        <translation>Ny</translation>
    </message>
    <message>
        <source>Draw a rectangular area with your mouse</source>
        <translation>Tegn et rektangulært område ved at bruge musen</translation>
    </message>
    <message>
        <source>Capture a screenshot of the last selected rectangular area</source>
        <translation>Tag et skærmbillede af den sidste markerede rektangulære område</translation>
    </message>
    <message>
        <source>Capture full screen including all monitors</source>
        <translation>Tag billeder af hele skærme på alle skærme</translation>
    </message>
    <message>
        <source>Capture screen where the mouse is located</source>
        <translation>Tag billedet hvor musmarkøren ligger</translation>
    </message>
    <message>
        <source>Capture window that currently has focus</source>
        <translation>Tag billede af vindue som har fokus</translation>
    </message>
    <message>
        <source>Capture that is currently under the mouse cursor</source>
        <translation>Tag billede af vindue under musmarkøren</translation>
    </message>
    <message>
        <source>Uses the screenshot Portal for taking screenshot</source>
        <translation type="unfinished">Bruger skærmbilledsportal</translation>
    </message>
</context>
<context>
    <name>ContactTab</name>
    <message>
        <source>Community</source>
        <translation>Fællesskabet</translation>
    </message>
    <message>
        <source>Bug Reports</source>
        <translation>Fejlrapporter</translation>
    </message>
    <message>
        <source>If you have general questions, ideas or just want to talk about ksnip,&lt;br/&gt;please join our %1 or our %2 server.</source>
        <translation>Har du nogle generelle spørgsmål, ideer, eller hvis du vil bare snakke om Ksnip,&lt;br/&gt;
være sød at slutte dig til vores %1 eller %2 server.</translation>
    </message>
    <message>
        <source>Please use %1 to report bugs.</source>
        <translation>Vær sød at bruge %1 til fejlrepportering.</translation>
    </message>
</context>
<context>
    <name>CopyAsDataUriOperation</name>
    <message>
        <source>Failed to copy to clipboard</source>
        <translation>Kopiering til udklipsholderen mislykkedes</translation>
    </message>
    <message>
        <source>Failed to copy to clipboard as base64 encoded image.</source>
        <translation>Kopiering til udklipsholderen som base64 indkodet billede mislykkedes.</translation>
    </message>
    <message>
        <source>Copied to clipboard</source>
        <translation>Kopieret til udklipsholderen</translation>
    </message>
    <message>
        <source>Copied to clipboard as base64 encoded image.</source>
        <translation>Kopieret til udklipsholderen som base64 indkodet billede.</translation>
    </message>
</context>
<context>
    <name>DeleteImageOperation</name>
    <message>
        <source>Delete Image</source>
        <translation>Slet billede</translation>
    </message>
    <message>
        <source>The item &apos;%1&apos; will be deleted.
Do you want to continue?</source>
        <translation>Elementet %1 vil blive slettet.
Vil du fortsætte?</translation>
    </message>
</context>
<context>
    <name>DonateTab</name>
    <message>
        <source>Donations are always welcome</source>
        <translation>Donationer er altid velkomne</translation>
    </message>
    <message>
        <source>Donation</source>
        <translation>Donation</translation>
    </message>
    <message>
        <source>ksnip is a non-profitable copyleft libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
        <translation>Ksnip er et ikke-kommercielt libre software projekt, men&lt;br/&gt;den har stadigvæk nogle omkostninger der skal dækkes&lt;br/&gt;ligesom domæne omkostninger eller hardware omkostninger for support på tværs af styresystemmer.</translation>
    </message>
    <message>
        <source>If you want to help or just want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that %1here%2.</source>
        <translation>Hvis du vil hjælpe eller sætte pris på det arbejde de laver&lt;br/&gt;ved at give udviklerne et glas øl eller en kop kaffe, kan du gøre det %1here2%.</translation>
    </message>
    <message>
        <source>Become a GitHub Sponsor?</source>
        <translation>Bliv GitHub Sponsor?</translation>
    </message>
    <message>
        <source>Also possible, %1here%2.</source>
        <translation>Også muligt, %1her%1.</translation>
    </message>
</context>
<context>
    <name>EmptyActionSettingTab</name>
    <message>
        <source>Add new actions by pressing the &apos;Add&apos; tab button.</source>
        <translation>Tilføj nye handlinger ved at trykke på &apos;Tilføj&apos; fanebjælkeknappen.</translation>
    </message>
</context>
<context>
    <name>EnumTranslator</name>
    <message>
        <source>Rectangular Area</source>
        <translation>Firkantet Område</translation>
    </message>
    <message>
        <source>Last Rectangular Area</source>
        <translation>Sidste Firkantet Område</translation>
    </message>
    <message>
        <source>Full Screen (All Monitors)</source>
        <translation>Fuld Skærm (Alle Skærme)</translation>
    </message>
    <message>
        <source>Current Screen</source>
        <translation>Nuværende Skærm</translation>
    </message>
    <message>
        <source>Active Window</source>
        <translation>Aktivt Vindue</translation>
    </message>
    <message>
        <source>Window Under Cursor</source>
        <translation>Vindue Under Markør</translation>
    </message>
    <message>
        <source>Screenshot Portal</source>
        <translation>Skærmbilledsportal</translation>
    </message>
</context>
<context>
    <name>FtpUploaderSettings</name>
    <message>
        <source>Force anonymous upload.</source>
        <translation>Tving anonym overførsel</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>URL-adresse</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Brugernavn</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Adgangskode</translation>
    </message>
    <message>
        <source>FTP Uploader</source>
        <translation>FTP overførselsværktoj</translation>
    </message>
</context>
<context>
    <name>HandleUploadResultOperation</name>
    <message>
        <source>Upload Successful</source>
        <translation>Overførsel Succesfuld</translation>
    </message>
    <message>
        <source>Unable to save temporary image for upload.</source>
        <translation>Ikke i stand til at gemme midlertidligt billede for overførsel.</translation>
    </message>
    <message>
        <source>Unable to start process, check path and permissions.</source>
        <translation>Ikke i stand til at starte processen, check sti og rettigheder.</translation>
    </message>
    <message>
        <source>Process crashed</source>
        <translation>Processen crashede</translation>
    </message>
    <message>
        <source>Process timed out.</source>
        <translation>Processen tidsudløbet.</translation>
    </message>
    <message>
        <source>Process read error.</source>
        <translation>Proces læsefejl.</translation>
    </message>
    <message>
        <source>Process write error.</source>
        <translation>Proces skrivefejl.</translation>
    </message>
    <message>
        <source>Web error, check console output.</source>
        <translation>Netværksfejl, check konsoleudskrift.</translation>
    </message>
    <message>
        <source>Upload Failed</source>
        <translation>Overførsel Mislykkedes</translation>
    </message>
    <message>
        <source>Script wrote to StdErr.</source>
        <translation>Script skrev til StdErr.</translation>
    </message>
    <message>
        <source>FTP Upload finished successfully.</source>
        <translation>FTP Overførsel færdig succesfuldt.</translation>
    </message>
    <message>
        <source>Unknown error.</source>
        <translation>Ukendt fejl.</translation>
    </message>
    <message>
        <source>Connection Error.</source>
        <translation>Forbindelsesfejl.</translation>
    </message>
    <message>
        <source>Permission Error.</source>
        <translation>Rettighedsfejl.</translation>
    </message>
    <message>
        <source>Upload script %1  finished successfully.</source>
        <translation>Overførsel af script %1 færdig succesfuldt.</translation>
    </message>
    <message>
        <source>Uploaded to %1</source>
        <translation>Overført til %1</translation>
    </message>
</context>
<context>
    <name>HotKeySettings</name>
    <message>
        <source>Enable Global HotKeys</source>
        <translation>Aktiver Globale Genvejstaster</translation>
    </message>
    <message>
        <source>Capture Rect Area</source>
        <translation>Tag Skærmbillede Af Firkantet Område</translation>
    </message>
    <message>
        <source>Capture Last Rect Area</source>
        <translation>Tag Skærmbillede Af Den Sidste Firkantet Område</translation>
    </message>
    <message>
        <source>Capture Full Screen</source>
        <translation>Tag Skærmbillede Af Komplet Skrivebord</translation>
    </message>
    <message>
        <source>Capture current Screen</source>
        <translation>Tag Skærmbillede Af Den Nuværende Skrivebord</translation>
    </message>
    <message>
        <source>Capture active Window</source>
        <translation>Tag skærmbillede af aktivt vindue</translation>
    </message>
    <message>
        <source>Capture Window under Cursor</source>
        <translation>Tag skærmbillede af vindue som er under markør</translation>
    </message>
    <message>
        <source>Global HotKeys</source>
        <translation>Globale genvejstaster</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Ryd</translation>
    </message>
    <message>
        <source>Capture using Portal</source>
        <translation>Tag skærmbillede ved at bruge Portal</translation>
    </message>
    <message>
        <source>HotKeys are currently supported only for Windows and X11.
Disabling this option makes also the action shortcuts ksnip only.</source>
        <translation>På nuværende tidspunkt understøttes genvejstester kun af Windows og X11.
Deaktivering af denne valgmulighed gør at handlingsgenveje er begrænset kun til Ksnip.</translation>
    </message>
</context>
<context>
    <name>ImageGrabberSettings</name>
    <message>
        <source>Capture mouse cursor on screenshot</source>
        <translation>Tag musmarkør med i skærmbillede</translation>
    </message>
    <message>
        <source>Should mouse cursor be visible on
screenshots.</source>
        <translation>Om musmarkør burde være synlig
i skærmbillede.</translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation>Billedgriber</translation>
    </message>
    <message>
        <source>Generic Wayland implementations that use
XDG-DESKTOP-PORTAL handle screen scaling
differently. Enabling this option will
determine the current screen scaling and
apply that to the screenshot in ksnip.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GNOME and KDE Plasma support their own Wayland
and the Generic XDG-DESKTOP-PORTAL screenshots.
Enabling this option will force KDE Plasma and
GNOME to use the XDG-DESKTOP-PORTAL screenshots.
Change in this option require a ksnip restart.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Main Window after capturing screenshot</source>
        <translation>Vis hovedvindue efter have taget skærmbillede</translation>
    </message>
    <message>
        <source>Hide Main Window during screenshot</source>
        <translation>Skjul hovedvindue mens skærmbillede tages</translation>
    </message>
    <message>
        <source>Hide Main Window when capturing a new screenshot.</source>
        <translation>Skjul hovedvindue mens nyt skærmbillede tages.</translation>
    </message>
    <message>
        <source>Show Main Window after capturing a new screenshot
when the Main Window was hidden or minimize.</source>
        <translation>Vis hovedvindue efter have taget nyt skærmbillede
når hovedvindue var skjult eller minimeret.</translation>
    </message>
    <message>
        <source>Force Generic Wayland (xdg-desktop-portal) Screenshot</source>
        <translation>Tving generisk Wayland (xdg-skrivebord-portal) skærmbillede</translation>
    </message>
    <message>
        <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
        <translation>Skaler generisk Wayland (xdg.desktop.portal) skærmbilleder</translation>
    </message>
    <message>
        <source>Implicit capture delay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This delay is used when no delay was selected in
the UI, it allows ksnip to hide before taking
a screenshot. This value is not applied when
ksnip was already minimized. Reducing this value
can have the effect that ksnip&apos;s main window is
visible on the screenshot.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgurHistoryDialog</name>
    <message>
        <source>Imgur History</source>
        <translation>Imgur historie</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Luk</translation>
    </message>
    <message>
        <source>Time Stamp</source>
        <translation>Tidsstempel</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>Link</translation>
    </message>
    <message>
        <source>Delete Link</source>
        <translation>Slet link</translation>
    </message>
</context>
<context>
    <name>ImgurUploader</name>
    <message>
        <source>Upload to imgur.com finished!</source>
        <translation>Overførsel til imgur.com færdig!</translation>
    </message>
    <message>
        <source>Received new token, trying upload again…</source>
        <translation>Nyt token modtaget, prøver at overføre på ny…</translation>
    </message>
    <message>
        <source>Imgur token has expired, requesting new token…</source>
        <translation>Imgur token udløbet, anmoder om nyt token…</translation>
    </message>
</context>
<context>
    <name>ImgurUploaderSettings</name>
    <message>
        <source>Force anonymous upload</source>
        <translation>Tving anonym overførsel</translation>
    </message>
    <message>
        <source>After uploading open Imgur link in default browser</source>
        <translation>Efter færdig overførsel åbn Imgur i standardbrowser</translation>
    </message>
    <message>
        <source>Link directly to image</source>
        <translation>Link direkt til billede</translation>
    </message>
    <message>
        <source>Always copy Imgur link to clipboard</source>
        <translation>Altid kopier Imgur link til udklipsholder</translation>
    </message>
    <message>
        <source>Client ID</source>
        <translation>Klient ID</translation>
    </message>
    <message>
        <source>Client Secret</source>
        <translation>Hemmelig klient</translation>
    </message>
    <message>
        <source>PIN</source>
        <translation>PIN</translation>
    </message>
    <message>
        <source>Enter imgur Pin which will be exchanged for a token.</source>
        <translation>Skriv Imgur PIN som vil blive vekslet til et token.</translation>
    </message>
    <message>
        <source>Get PIN</source>
        <translation>Få PIN</translation>
    </message>
    <message>
        <source>Get Token</source>
        <translation>Få token</translation>
    </message>
    <message>
        <source>Imgur History</source>
        <translation>Imgur historie</translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation>Imgur overførselsværktøj</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Brugernavn</translation>
    </message>
    <message>
        <source>Waiting for imgur.com…</source>
        <translation>Venter på imgur.com…</translation>
    </message>
    <message>
        <source>Imgur.com token successfully updated.</source>
        <translation>Imgur.com token opdateret succesfuldt.</translation>
    </message>
    <message>
        <source>Imgur.com token update error.</source>
        <translation>Imgur.com token opdateringsfejl.</translation>
    </message>
    <message>
        <source>Base Url:</source>
        <translation>Basis-Url:</translation>
    </message>
    <message>
        <source>Base url that will be used for communication with Imgur.
Changing requires restart.</source>
        <translation>Basis-Url der vil blive brugt for kommunikation med Imgur.
Ændring kræver genstart.</translation>
    </message>
    <message>
        <source>Clear Token</source>
        <translation>Ryd token</translation>
    </message>
    <message>
        <source>Upload title:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Upload description:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LoadImageFromFileOperation</name>
    <message>
        <source>Unable to open image</source>
        <translation>Ikke i stand til at åbne billede</translation>
    </message>
    <message>
        <source>Unable to open image from path %1</source>
        <translation>Ikke i stand til at åbne billede fra sti %1</translation>
    </message>
</context>
<context>
    <name>MainToolBar</name>
    <message>
        <source>New</source>
        <translation>Ny</translation>
    </message>
    <message>
        <source>Delay in seconds between triggering
and capturing screenshot.</source>
        <translation>Udsættelsen i sekunder mellem udløsning og
tagning af skærmbillede.</translation>
    </message>
    <message>
        <source>s</source>
        <extracomment>The small letter s stands for seconds.</extracomment>
        <translation>s</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Gem</translation>
    </message>
    <message>
        <source>Save Screen Capture to file system</source>
        <translation>Gem skærmbillede til filsystem</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopier</translation>
    </message>
    <message>
        <source>Copy Screen Capture to clipboard</source>
        <translation>Kopier skærmbillede til udklipsholderen</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Fortryd</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Annuler fortryd</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>Beskær</translation>
    </message>
    <message>
        <source>Crop Screen Capture</source>
        <translation>Beskær skærmbillede</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Værktøjer</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Unable to show image</source>
        <translation>Ikke i stand til at vise billede</translation>
    </message>
    <message>
        <source>Unsaved</source>
        <translation>Ikke gemt</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Overfør</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Udskriv</translation>
    </message>
    <message>
        <source>Opens printer dialog and provide option to print image</source>
        <translation>Åbner printers dialog og angiver valgmulighed til at udskrive billede</translation>
    </message>
    <message>
        <source>Print Preview</source>
        <translation>Forhåndsvisning af udskrift</translation>
    </message>
    <message>
        <source>Opens Print Preview dialog where the image orientation can be changed</source>
        <translation>Åbner forhåndsvisning af udskrift dialog hvor billedorientering kan ændres</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Skaler</translation>
    </message>
    <message>
        <source>Add Watermark</source>
        <translation>T</translation>
    </message>
    <message>
        <source>Add Watermark to captured image. Multiple watermarks can be added.</source>
        <translation>Tilføj vandmærke til taget skærmbillede. Flere vandmærker kan tilføjes.</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Afslut</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Indstillinger</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Om</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Åbn</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fil</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Rediger</translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <translation>&amp;Valgmuligheder</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hjælp</translation>
    </message>
    <message>
        <source>Save As...</source>
        <translation>Gem som...</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Indsæt</translation>
    </message>
    <message>
        <source>Paste Embedded</source>
        <translation>Indsæt indlejret</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Fastgør</translation>
    </message>
    <message>
        <source>Pin screenshot to foreground in frameless window</source>
        <translation>Fastgør skærmbillede til forgrund i rammeløst vindue</translation>
    </message>
    <message>
        <source>No image provided but one was expected.</source>
        <translation type="unfinished">Ingen tilgængelige billeder, men et er forventet</translation>
    </message>
    <message>
        <source>Copy Path</source>
        <translation>Kopier sti</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Åbn mappe</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Visning</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slet</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Omdøb</translation>
    </message>
    <message>
        <source>Open Images</source>
        <translation>Åbn billeder</translation>
    </message>
    <message>
        <source>Show Docks</source>
        <translation>Vis docks</translation>
    </message>
    <message>
        <source>Hide Docks</source>
        <translation>Skjul docks</translation>
    </message>
    <message>
        <source>Copy as data URI</source>
        <translation>Kopier som data URI</translation>
    </message>
    <message>
        <source>Open &amp;Recent</source>
        <translation type="unfinished">Åbn &amp;Senest</translation>
    </message>
    <message>
        <source>Modify Canvas</source>
        <translation>Modificer kanvas</translation>
    </message>
    <message>
        <source>Upload triggerCapture to external source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy triggerCapture to system clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scale Image</source>
        <translation>Skaler billede</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Roter</translation>
    </message>
    <message>
        <source>Rotate Image</source>
        <translation>Roter billede</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Handlinger</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation>Billedfiler</translation>
    </message>
    <message>
        <source>Save All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OCR</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MultiCaptureHandler</name>
    <message>
        <source>Save</source>
        <translation>Gem</translation>
    </message>
    <message>
        <source>Save As</source>
        <translation>Gem som</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Åbn mappe</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopier</translation>
    </message>
    <message>
        <source>Copy Path</source>
        <translation>Kopier sti</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slet</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Omdøb</translation>
    </message>
    <message>
        <source>Save All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NewCaptureNameProvider</name>
    <message>
        <source>Capture</source>
        <translation>Indfang</translation>
    </message>
</context>
<context>
    <name>OcrWindowCreator</name>
    <message>
        <source>OCR Window %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PinWindow</name>
    <message>
        <source>Close</source>
        <translation>Luk</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Luk andre</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Luk alle</translation>
    </message>
</context>
<context>
    <name>PinWindowCreator</name>
    <message>
        <source>OCR Window %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PluginsSettings</name>
    <message>
        <source>Search Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default</source>
        <translation type="unfinished">Standard</translation>
    </message>
    <message>
        <source>The directory where the plugins are located.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse</source>
        <translation type="unfinished">Gennemse</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished">Navn</translation>
    </message>
    <message>
        <source>Version</source>
        <translation type="unfinished">Version</translation>
    </message>
    <message>
        <source>Detect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plugin location</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ProcessIndicator</name>
    <message>
        <source>Processing</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenameOperation</name>
    <message>
        <source>Image Renamed</source>
        <translation>Billede omdøbt</translation>
    </message>
    <message>
        <source>Image Rename Failed</source>
        <translation>Billedomdøbning mislykkedes</translation>
    </message>
    <message>
        <source>Rename image</source>
        <translation>Omdøb billede</translation>
    </message>
    <message>
        <source>New filename:</source>
        <translation>Nyt filnavn:</translation>
    </message>
    <message>
        <source>Successfully renamed image to %1</source>
        <translation>Succesfuldt omdøbt billede til %1</translation>
    </message>
    <message>
        <source>Failed to rename image to %1</source>
        <translation>Omdøbning af billede %1 mislykkedes</translation>
    </message>
</context>
<context>
    <name>SaveOperation</name>
    <message>
        <source>Save As</source>
        <translation>Gem som</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Alle filer</translation>
    </message>
    <message>
        <source>Image Saved</source>
        <translation>Billede gemt</translation>
    </message>
    <message>
        <source>Saving Image Failed</source>
        <translation>Fejl: Kunne ikke gemme billede</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation>Billedfiler</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Gemt til %1</translation>
    </message>
    <message>
        <source>Failed to save image to %1</source>
        <translation>Fejl: Kunne ikke gemme billede til %1</translation>
    </message>
</context>
<context>
    <name>SaverSettings</name>
    <message>
        <source>Automatically save new captures to default location</source>
        <translation>Gem automatisk nye skærmbilleder til standardplacering</translation>
    </message>
    <message>
        <source>Prompt to save before discarding unsaved changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remember last Save Directory</source>
        <translation>Husk den seneste gemmemappe</translation>
    </message>
    <message>
        <source>When enabled will overwrite the save directory stored in settings
with the latest save directory, for every save.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture save location and filename</source>
        <translation>Gemmested og filnavn</translation>
    </message>
    <message>
        <source>Supported Formats are JPG, PNG and BMP. If no format provided, PNG will be used as default.
Filename can contain following wildcards:
- $Y, $M, $D for date, $h, $m, $s for time, or $T for time in hhmmss format.
- Multiple consecutive # for counter. #### will result in 0001, next capture would be 0002.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Gennemse</translation>
    </message>
    <message>
        <source>Saver Settings</source>
        <translation>Gemmeindstillinger</translation>
    </message>
    <message>
        <source>Capture save location</source>
        <translation>Gemmeplacering</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>Factor</source>
        <translation>Faktor</translation>
    </message>
    <message>
        <source>Save Quality</source>
        <translation>Gemmekvalitet</translation>
    </message>
    <message>
        <source>Specify 0 to obtain small compressed files, 100 for large uncompressed files.
Not all image formats support the full range, JPEG does.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Overwrite file with same name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScriptUploaderSettings</name>
    <message>
        <source>Copy script output to clipboard</source>
        <translation>Kopier scriptuddata til udklipsholder</translation>
    </message>
    <message>
        <source>Script:</source>
        <translation>Script:</translation>
    </message>
    <message>
        <source>Path to script that will be called for uploading. During upload the script will be called
with the path to a temporary png file as a single argument.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Gennemse</translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation>Scriptoverførselsværktøj</translation>
    </message>
    <message>
        <source>Select Upload Script</source>
        <translation>Valg overførselsscript</translation>
    </message>
    <message>
        <source>Stop when upload script writes to StdErr</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Marks the upload as failed when script writes to StdErr.
Without this setting errors in the script will be unnoticed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filter:</translation>
    </message>
    <message>
        <source>RegEx Expression. Only copy to clipboard what matches the RegEx Expression.
When omitted, everything is copied.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Indstillinger</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Fortryd</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>Program</translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation>Billedgriberen</translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation>Imgur overførselsværktøj</translation>
    </message>
    <message>
        <source>Annotator</source>
        <translation>Annotator</translation>
    </message>
    <message>
        <source>HotKeys</source>
        <translation>Genvejstaster</translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation>Overfører</translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation>Scriptoverførselsværktøj</translation>
    </message>
    <message>
        <source>Saver</source>
        <translation type="unfinished">???</translation>
    </message>
    <message>
        <source>Stickers</source>
        <translation>Klistemærker</translation>
    </message>
    <message>
        <source>Snipping Area</source>
        <translation>Afklipningsområde</translation>
    </message>
    <message>
        <source>Tray Icon</source>
        <translation>Statusfeltikon</translation>
    </message>
    <message>
        <source>Watermark</source>
        <translation>Vandmærke</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Handlinger</translation>
    </message>
    <message>
        <source>FTP Uploader</source>
        <translation>FTP Overførselsværktøj</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search Settings...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SnippingAreaResizerInfoText</name>
    <message>
        <source>Resize selected rect using the handles or move it by dragging the selection.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use arrow keys to move the selection.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use arrow keys while pressing CTRL to move top left handle.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use arrow keys while pressing ALT to move bottom right handle.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This message can be disabled via settings.</source>
        <translation type="unfinished">Denne meddelelse kan deaktiveres i indstillingerne.</translation>
    </message>
    <message>
        <source>Confirm selection by pressing ENTER/RETURN or mouse double-click anywhere.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Abort by pressing ESC.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SnippingAreaSelectorInfoText</name>
    <message>
        <source>Click and Drag to select a rectangular area or press ESC to quit.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hold CTRL pressed to resize selection after selecting.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hold CTRL pressed to prevent resizing after selecting.</source>
        <translation>Tryk og hold CTRL nede for at undgå størrelsesændring efter markering.</translation>
    </message>
    <message>
        <source>Operation will be canceled after 60 sec when no selection made.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This message can be disabled via settings.</source>
        <translation>Denne meddelelse kan deaktiveres i indstillingerne.</translation>
    </message>
</context>
<context>
    <name>SnippingAreaSettings</name>
    <message>
        <source>Freeze Image while snipping</source>
        <translation>Frys billede under afklipning</translation>
    </message>
    <message>
        <source>When enabled will freeze the background while
selecting a rectangular region. It also changes
the behavior of delayed screenshots, with this
option enabled the delay happens before the
snipping area is shown and with the option disabled
the delay happens after the snipping area is shown.
This feature is always disabled for Wayland and always
enabled for MacOs.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show magnifying glass on snipping area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show a magnifying glass which zooms into
the background image. This option only works
with &apos;Freeze Image while snipping&apos; enabled.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Snipping Area rulers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Horizontal and vertical lines going from
desktop edges to cursor on snipping area.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Snipping Area position and size info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When left mouse button is not pressed the position
is shown, when the mouse button is pressed,
the size of the select area is shown left
and above from the captured area.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow resizing rect area selection by default</source>
        <translation>Som standardindstilling tillad størrelsesændring af firkantet område</translation>
    </message>
    <message>
        <source>When enabled will, after selecting a rect
area, allow resizing the selection. When
done resizing the selection can be confirmed
by pressing return.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Snipping Area info text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snipping Area cursor color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sets the color of the snipping area cursor.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snipping Area cursor thickness</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sets the thickness of the snipping area cursor.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snipping Area</source>
        <translation>Afklipningsområde</translation>
    </message>
    <message>
        <source>Snipping Area adorner color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sets the color of all adorner elements
on the snipping area.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snipping Area Transparency</source>
        <translation>Afklipningsområdes gennemsigtighed</translation>
    </message>
    <message>
        <source>Alpha for not selected region on snipping area.
Smaller number is more transparent.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable Snipping Area offset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When enabled will apply the configured
offset to the Snipping Area position which
is required when the position is not
correctly calculated. This is sometimes
required with screen scaling enabled.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>X</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Y</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StickerSettings</name>
    <message>
        <source>Up</source>
        <translation>Op</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>Ned</translation>
    </message>
    <message>
        <source>Use Default Stickers</source>
        <translation>Brug standardklistemærker</translation>
    </message>
    <message>
        <source>Sticker Settings</source>
        <translation>Klistemærkeindstillinger</translation>
    </message>
    <message>
        <source>Vector Image Files (*.svg)</source>
        <translation>Vektorbilledfiler (*.svg)</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Tilføj</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Fjern</translation>
    </message>
    <message>
        <source>Add Stickers</source>
        <translation>Tilføj klistemærker</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <source>Show Editor</source>
        <translation>Vis redigeringsprogram</translation>
    </message>
</context>
<context>
    <name>TrayIconSettings</name>
    <message>
        <source>Use Tray Icon</source>
        <translation>Brug statusfeltikon</translation>
    </message>
    <message>
        <source>When enabled will add a Tray Icon to the TaskBar if the OS Window Manager supports it.
Change requires restart.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Minimize to Tray</source>
        <translation>Minimer til statusfelt</translation>
    </message>
    <message>
        <source>Start Minimized to Tray</source>
        <translation>Start minimeret i statusfeltet</translation>
    </message>
    <message>
        <source>Close to Tray</source>
        <translation>Luk til statusfeltet</translation>
    </message>
    <message>
        <source>Show Editor</source>
        <translation>Vis redigeringsprogram</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation>Indfang</translation>
    </message>
    <message>
        <source>Default Tray Icon action</source>
        <translation>Standard statusfeltsikonhandling</translation>
    </message>
    <message>
        <source>Default Action that is triggered by left clicking the tray icon.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tray Icon Settings</source>
        <translation>Statusfeltikon indstillinger</translation>
    </message>
    <message>
        <source>Use platform specific notification service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When enabled will use try to use platform specific notification
service when such exists. Change requires restart to take effect.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display Tray Icon notifications</source>
        <translation>Vis statusfeltikonsnotifikationer</translation>
    </message>
</context>
<context>
    <name>UpdateWatermarkOperation</name>
    <message>
        <source>Select Image</source>
        <translation>Valg billede</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation>Billedfiler</translation>
    </message>
</context>
<context>
    <name>UploadOperation</name>
    <message>
        <source>Upload Script Required</source>
        <translation>Overførselsscript påkrævet</translation>
    </message>
    <message>
        <source>Please add an upload script via Options &gt; Settings &gt; Upload Script</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture Upload</source>
        <translation>Billedoverførsel</translation>
    </message>
    <message>
        <source>You are about to upload the image to an external destination, do you want to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UploaderSettings</name>
    <message>
        <source>Ask for confirmation before uploading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Uploader Type:</source>
        <translation>Overførselstype:</translation>
    </message>
    <message>
        <source>Imgur</source>
        <translation>Imgur</translation>
    </message>
    <message>
        <source>Script</source>
        <translation>Script</translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation>Uploaderen</translation>
    </message>
    <message>
        <source>FTP</source>
        <translation>FTP</translation>
    </message>
</context>
<context>
    <name>VersionTab</name>
    <message>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <source>Build</source>
        <translation type="unfinished">Version</translation>
    </message>
    <message>
        <source>Using:</source>
        <translation>Bruger:</translation>
    </message>
</context>
<context>
    <name>WatermarkSettings</name>
    <message>
        <source>Watermark Image</source>
        <translation>Vandmærkebillede</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Opdater</translation>
    </message>
    <message>
        <source>Rotate Watermark</source>
        <translation>Roter vandmærke</translation>
    </message>
    <message>
        <source>When enabled, Watermark will be added with a rotation of 45°</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Watermark Settings</source>
        <translation>Vandmærkeindstillinger</translation>
    </message>
</context>
</TS>
